==> oci-2.14.1-py2.py3-none-any.whl: oci/resource_manager/models/terraform_version_collection.py <==
# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TerraformVersionCollection(object):
    """
    The list of Terraform versions supported for use with stacks.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new TerraformVersionCollection object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param items:
            The value to assign to the items property of this TerraformVersionCollection.
        :type items: list[TerraformVersionSummary]

        """
        self.swagger_types = {
            'items': 'list[TerraformVersionSummary]'
        }

        self.attribute_map = {
            'items': 'items'
        }

        self._items = None

    @property
    def items(self):
        """
        Gets the items of this TerraformVersionCollection.
        Collection of supported Terraform versions.


        :return: The items of this TerraformVersionCollection.
        :rtype: list[TerraformVersionSummary]
        """
        return self._items

    @items.setter
    def items(self, items):
        """
        Sets the items of this TerraformVersionCollection.
        Collection of supported Terraform versions.


        :param items: The items of this TerraformVersionCollection.
        :type: list[TerraformVersionSummary]
        """
        self._items = items

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other

==> oci-2.60.0-py2.py3-none-any.whl: oci/resource_manager/models/terraform_version_collection.py <==
# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TerraformVersionCollection(object):
    """
    The list of Terraform versions supported for use with stacks.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new TerraformVersionCollection object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param items:
            The value to assign to the items property of this TerraformVersionCollection.
        :type items: list[oci.resource_manager.models.TerraformVersionSummary]

        """
        self.swagger_types = {
            'items': 'list[TerraformVersionSummary]'
        }

        self.attribute_map = {
            'items': 'items'
        }

        self._items = None

    @property
    def items(self):
        """
        **[Required]** Gets the items of this TerraformVersionCollection.
        Collection of supported Terraform versions.


        :return: The items of this TerraformVersionCollection.
        :rtype: list[oci.resource_manager.models.TerraformVersionSummary]
        """
        return self._items

    @items.setter
    def items(self, items):
        """
        Sets the items of this TerraformVersionCollection.
        Collection of supported Terraform versions.


        :param items: The items of this TerraformVersionCollection.
        :type: list[oci.resource_manager.models.TerraformVersionSummary]
        """
        self._items = items

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
